@@ -64,8 +64,10 @@ use Log::Log4perl;
 use Data::Queue;
 use Scalar::Util qw(looks_like_number);
 Log::Log4perl->wrapper_register(__PACKAGE__);
-BEGIN { with 'Log::LogMethods'; }
+BEGIN {
+with 'Log::LogMethods';
 with 'Data::Result::Moo';
+}
 use AnyEvent::Loop;
 use Data::Dumper;
 use HTTP::Response;
@@ -75,7 +77,7 @@ use AnyEvent::HTTP::Request;
 use MooX::Types::MooseLike::Base qw(:all);
 use AnyEvent::HTTP::Response;
 use Carp qw(croak);
-our $VERSION='1.001';
+our $VERSION='1.002';
 
 sub BUILD {
   my ($self)=@_;
